Molten API
molten-api is the web API interface for the Molten Document and Workflow Management system.
This crate provides Axum-based REST endpoints and handlers.
This crate is under active development and is not yet stable. If this crate has been abandoned, please message me and we can discuss ownership transfer.
Modules
- error
- Contains error types and their HTTP response conversions for the Molten API.
- handlers
- This module serves as a re-export module for various API handlers within the
molten-apicrate. - startup
- This module handles the application startup process for the Molten API.
- state
- Defines the shared application state for the Molten API.
- telemetry
- This module provides utilities for setting up application-wide logging and tracing.