Function get_document
Source pub async fn get_document(
__arg0: State<AppState>,
__arg1: Path<String>,
) -> Result<Json<Document>, ApiError>
Retrieve a document definition by id.
Route
GET /documents/{id}
Errors
- Returns an error if the document does not exist.
- Returns an error if the underlying storage operation fails.